@@ -16,16 +16,16 @@
 import os
 import sys
 import curses
+import logging
 import message
 import constant
 import ConfigParser
 import curses.ascii
 import oauth2 as oauth
 from utils import encode
-
 try:
     from urlparse import parse_qsl
-except:
+except ImportError:
     from cgi import parse_qsl
 
 class Config(object):
@@ -42,13 +42,13 @@ class Config(object):
 
         self.set_path(args)
         self.check_for_default_config() 
+        self.conf = ConfigParser.RawConfigParser()
+        self.conf.read(self.config_file)
         if not os.path.isfile(self.token_file):
             self.new_account()
         else:
             self.parse_token()
 
-        self.conf = ConfigParser.RawConfigParser()
-        self.conf.read(self.config_file)
         self.parse_config()
 
     def init_config(self):
@@ -176,6 +176,7 @@ class Config(object):
         self.parse_keys()
         self.parse_params()
         self.parse_filter()
+        self.init_logger()
 
     def parse_color(self):
         for c in self.colors:
@@ -281,8 +282,28 @@ class Config(object):
             if int(self.conf.get('params', 'old_skool_border')) == 1:
                 self.params['old_skool_border'] = True
 
+        if self.conf.has_option('params', 'consumer_key'):
+            self.token['identica']['consumer_key'] = self.conf.get('params', 'consumer_key')
+
+        if self.conf.has_option('params', 'consumer_secret'):
+            self.token['identica']['consumer_secret'] = self.conf.get('params', 'consumer_secret')
+
+        if self.conf.has_option('params', 'logging_level'):
+            self.params['logging_level'] = self.conf.get('params', 'logging_level')
+
         if self.conf.has_option('params', 'url_shorter'):
-            self.params['url_shorter'] = self.conf.get('params', 'url_shorter')
+            shortener = self.params['url_shorter'] = self.conf.get('params', 'url_shorter')
+            if shortener == 'googl': 
+                self.check_google_tokens()
+
+    def check_google_tokens(self):
+        try:
+            from shorter.googl import GooglUrlShorter
+        except ImportError:
+            print 'please install google-api-python-client and python-gflags'
+            sys.exit(1)
+        GooglUrlShorter().register_token()
+        
     
     def parse_filter(self):
 
@@ -300,6 +321,28 @@ class Config(object):
         if self.conf.has_option('filter', 'except'):
             self.filter['except'] = self.conf.get('filter', 'except').split(' ')
 
+    def init_logger(self):
+        log_file = self.xdg_config + '/tyrs/tyrs.log'
+        lvl = self.init_logger_level()
+
+        logging.basicConfig(
+            filename=log_file,
+            level=lvl,
+            format='%(asctime)s %(levelname)s - %(message)s',
+            datefmt='%d/%m/%Y %H:%M:%S',
+            )
+        logging.info('Tyrs starting...')
+
+    def init_logger_level(self):
+        lvl = int(self.params['logging_level'])
+        if lvl == 1:
+            return logging.DEBUG
+        elif lvl == 2:
+            return logging.INFO
+        elif lvl == 3:
+            return logging.WARNING
+        elif lvl == 4:
+            return logging.ERROR
 
     def authorization(self):
         ''' This function from python-twitter developers '''
@@ -323,9 +366,13 @@ class Config(object):
         else:
             base_url = self.base_url
 
+        print 'base_url:{0}'.format(base_url)
+
 
         REQUEST_TOKEN_URL          = base_url + '/oauth/request_token'
         if self.service == 'identica':
+            if base_url != 'https://identi.ca/api':
+                self.parse_config()
             REQUEST_TOKEN_URL += '?oauth_callback=oob'
 
         ACCESS_TOKEN_URL           = base_url + '/oauth/access_token'
@@ -341,8 +388,7 @@ class Config(object):
         resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
 
         if resp['status'] != '200':
-            print encode(_('Invalid respond from ')) +self.service.capitalize()
-            + encode(_(' requesting temp token: %s')) % resp['status']
+            print encode(_('Invalid respond from ')) +self.service.capitalize() + encode(_(' requesting temp token: %s')) % str(resp['status'])
         else:
             request_token = dict(parse_qsl(content))
 
@@ -367,6 +413,7 @@ class Config(object):
             access_token  = dict(parse_qsl(content))
 
             if resp['status'] != '200':
+                print 'response:{0}'.format(resp['status'])
                 print encode(_('Request for access token failed: %s')) % resp['status']
                 print access_token
                 sys.exit()
@@ -374,6 +421,7 @@ class Config(object):
                 self.oauth_token = access_token['oauth_token']
                 self.oauth_token_secret = access_token['oauth_token_secret']
 
+
     def createTokenFile(self):
 
         if not os.path.isdir(self.tyrs_path):
@@ -393,3 +441,21 @@ class Config(object):
             conf.write(tokens)
 
         print encode(_('your account has been saved'))
+
+    def load_last_read(self):
+
+        try:
+            conf = ConfigParser.RawConfigParser()
+            conf.read(self.token_file)
+            return conf.get('token', 'last_read')
+        except:
+            return False
+
+    def save_last_read(self, last_read):
+
+        conf = ConfigParser.RawConfigParser()
+        conf.read(self.token_file)
+        conf.set('token', 'last_read', last_read)
+
+        with open(self.token_file, 'wb') as tokens:
+            conf.write(tokens)
