@@ -60,6 +60,7 @@ key = {
     'sendDM':            'D',
     'search':            's',
     'search_user':       'U',
+    'search_current_user': '^F',
     'search_myself':     '^U',
     'redraw':            '^L',
     'fav':               'b',
@@ -85,6 +86,7 @@ params = {
     'old_skool_border':     False,
     'box_position':         1,
     'url_shorter':          'ur1ca',
+    'logging_level':        3,
 }
 
 filter = {
