@@ -17,8 +17,18 @@ import tyrs
 import curses
 import curses.ascii
 from utils import encode, get_urls
-from shorter.ur1ca import Ur1caUrlShorter
-from shorter.bitly import BitLyUrlShorter
+try:
+    from shorter.ur1ca import Ur1caUrlShorter
+    from shorter.bitly import BitLyUrlShorter
+    from shorter.msudpl import MsudplUrlShorter
+    from shorter.custom import CustomUrlShorter
+except ImportError:
+    pass
+
+try:
+    from shorter.googl import GooglUrlShorter
+except ImportError:
+    pass
 
 class Editor(object):
 
@@ -171,7 +181,13 @@ class TweetEditor(Editor):
         service = self.conf.params['url_shorter']
         if service == 'bitly':
             self.shorter = BitLyUrlShorter() 
-        if service == 'ur1ca':
+        elif service == 'googl':
+            self.shorter = GooglUrlShorter()
+        elif service == 'msudpl':
+            self.shorter = MsudplUrlShorter()
+        elif service == 'custom':
+            self.shorter = CustomUrlShorter()
+        else:
             self.shorter = Ur1caUrlShorter()
 
 
